Keyboard shortcuts

Press or to navigate between chapters

Press S or / to search in the book

Press ? to show this help

Press Esc to hide this help

Samples Reference

Map

Here is a map of sample programs put under samples in the work tree of the project.

SampleTargets
assignment/addr_ofRvalue::RawPtr
assignment/aggregateRvalue::Aggregate
assignment/bin_opRvalue::BinaryOp
constOperand::Constant::*
assignment/discrRvalue::Discriminant
assignment/refRvalue::Ref
assignment/repeat_arrayRvalue::Repeat
assignment/set_discrStatementKind::SetDiscriminant
assignment/thread_local_refRvalue::ThreadLocalRef
assignment/un_opRvalue::UnaryOp
branching/assertTerminatorKind::Assert
branching/if_basicTerminatorKind::SwitchInt, if
branching/if_elseTerminatorKind::SwitchInt, if, else if, else
branching/if_letTerminatorKind::SwitchInt, if let
branching/match_basicTerminatorKind::SwitchInt, match
branching/match_enumTerminatorKind::SwitchInt, Rvalue::Discriminant, match <enum>
casting/numericRvalue::Cast, CastKind::IntTo*, CastKind::FloatTo*
casting/pointerRvalue::Cast, CastKind::PtrToPtr, CastKind::PointerCoercion, PointerCoercion::*
casting/subtypeRvalue::Cast, CastKind::Subtype
casting/transmuteRvalue::Cast, CastKind::Transmute
dropTerminatorKind::Drop, intrinsics::drop_glue
function/asyncAsync Functions, TyKind::CoroutineClosure
function/call_basicTerminatorKind::Call
function/closuresTyKind::Closure, Fn* traits, tupling/untupling arguments
function/coroutinesTyKind::Coroutine
function/shimsShimKind
intrinsics/atomicintrinsics::atomic_*
intrinsics/memory(Raw) Memory-related intrinsics
intrinsics/operatorsIntrinsic (arithmetic) operators
misc/intrinsicsMisc intrinsic usage
misc/leaf_attrUsing Leaf-specific attributes, #[leaf_attr::instrument]
misc/no_divergePushing/popping tags
misc/promotedPromoted bodies
misc/staticStatic items and accesses
place/deref_mutDereferencing mutable references
place/projection/downcastPlaceElem::Downcast
place/projection/fieldPlaceElem::Field
place/projection/indexPlaceElem::Index
place/projection/unwrap_unsafe_binderPlaceElem::UnwrapUnsafeBinder
sym_place/read#SymEx Reading symbolic places
sym_place/write#SymEx Writing to symbolic places
function/sym_*#SymEx Symbolic values transferred between functions
basicBasic algorithm implementations
crates/multi_file_binMulti-file crate compilation
crates/single_file_binSingle-file crate baseline
crates/with_depCrate with dependencies
crates/with_shared_depCrate with shared transitive dependency